@@ -1,9 +1,9 @@
 import os, re, copy
 import numpy as np
-from scipy.integrate import cumtrapz
+from scipy.integrate import cumtrapz, trapz
 from scipy.optimize import least_squares
 from collections import OrderedDict
-#from .debye import Debye
+from grsq.debye import Debye
 
 class RDF:
     ''' RDF Object.
@@ -65,15 +65,23 @@ class RDF:
     def __str__(self):
         return self.get_info()
 
-    def __repr__(self):
-        return self.get_info()
-
     def get_info(self):
         info = f'{self.name1}-{self.region1}--{self.name2}-{self.region2}: ' +\
                f'RDF with {self.n1} particles in {self.region1} and {self.n2} in {self.region2}. ' +\
                f'Volume: {self.volume}'
         return info
 
+    def coordination_number(self, r_min, r_max):
+        ''' Calculate the coordination number in the region: r_min >= r > r_max '''
+        r = self.r
+        g = self.g
+
+        r_mask = np.zeros(len(r), bool)
+        r_mask[(r >= r_min) & (r < r_max)] = True
+
+        rho_m = self.n2 / self.volume
+        return trapz(4 * np.pi * r[r_mask]**2 * rho_m * g[r_mask], dx=(r[1] - r[0]))
+
     def structure_factor(self):
         ''' Calculate the structure factor for a given RDF '''
         r = self.r
@@ -112,6 +120,7 @@ class RDF:
     def atomic_f0(self):
         ''' Calculate atomic form factors and
             update RDF object in place '''
+        from grsq import Debye
         db = Debye(self.qvec)
         self.f0_1 = db.atomic_f0(self.name1)
         self.f0_2 = db.atomic_f0(self.name2)
@@ -235,7 +244,12 @@ class RDFSet(OrderedDict):
             start = key.start
             if start is None:
                 start = 0
-            include = list(range(start, key.stop, step))
+            stop = key.stop
+            if stop is None:
+                stop = len(self.keys())
+            if stop < 0:
+                stop = len(self.keys()) + stop
+            include = list(range(start, stop, step))
             for i, (rdfkey, rdf) in enumerate(self.items()):
                 if i in include:
                     tmp[rdfkey] = rdf
@@ -249,11 +263,18 @@ class RDFSet(OrderedDict):
         else:
             raise Exception("RDF not in set")
 
+    def __add__(self, add):
+        tmp = RDFSet()
+        for key, rdf in self.items():
+            tmp[(rdf.name1, rdf.region1, rdf.name2, rdf.region2)] = rdf
+        for key, rdf in add.items():
+            tmp[(rdf.name1, rdf.region1, rdf.name2, rdf.region2)] = rdf
+        return tmp
+
     def add_rdf(self, rdf):
         self[(rdf.name1, rdf.region1, rdf.name2, rdf.region2)] = rdf
 
     def add_flipped(self, rdf):
-        # XXX Needs to be much more robust
         r_rdf = copy.copy(rdf)
         r_rdf.name2 = rdf.name1
         r_rdf.name1 = rdf.name2
@@ -424,48 +445,6 @@ class RDFSet(OrderedDict):
 
 
 ## Helper functions
-def load_rdfs(rdflist, stoich=None, damp=None):
-    ''' Make a list of RDF objects from a list of dat files from e.g. VMD
-
-        The list should contain paths to files in the following format:
-
-            gX_a-Y_b.dat
-
-        where X,Y is the atom type, and a,b is either u or v, for solUte
-        and solVent, respectively.
-
-        and the .dat files should contain (r, gr) columns.
-
-        If a stoichometry dict is provided, the n1 and n2
-        of the rdf objects will also be filled.
-
-    '''
-
-    rdfs = []
-    trslt = {'c': 'cross', 'u':'solute', 'v':'solvent'}
-
-    for rdffile in rdflist:
-        name = rdffile.split(os.sep)[-1]
-        # use reg exp since atom types can be 1 or 2 chars long:
-        atyp1 = re.search('g(.*?)_', name).group(1)
-        part1 = re.search(atyp1 + '_(.*?)-', name).group(1)
-
-        atyp2 = re.search('-(.*?)_', name).group(1)
-        part2 = re.search('-' +  atyp2 + '_(.*).dat', name).group(1)
-
-        dat = np.genfromtxt(rdffile)
-        rdf = RDF(dat[:, 0], dat[:, 1],
-                  atyp1, atyp2,
-                  trslt[part1], trslt[part2], damp=damp)
-
-        if stoich:
-            rdf.n1 = stoich[(atyp1, trslt[part1])]
-            rdf.n2 = stoich[(atyp2, trslt[part2])]
-
-        rdfs.append(rdf)
-
-    return rdfs
-
 def rdfset_from_dir(dirname, prmtop=None, volume=None, stoich=None):
     ''' Read in a directory of rdf files with the naming convention:
             gEl1_w1-El2_w2.dat
@@ -542,7 +521,3 @@ def rdfset_from_dir(dirname, prmtop=None, volume=None, stoich=None):
 
     return set_uc
 
-
-if __name__ == "__main__":
-    # Do something if this file is invoked on its own
-    print('Check the tests for usage examples')
